.. AioTx documentation master file, created by
   sphinx-quickstart on Fri May 3 16:38:46 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to AioTx's documentation!
==================================

.. toctree::
   :maxdepth: 10
   :caption: Available Clients:

   clients/bsc_client/index
   clients/eth_client/index
   clients/btc_client/index

.. toctree::
   :maxdepth: 10
   :caption: Monitoring:

   monitoring

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`